@@ -1,5 +1,6 @@
 // Copyright (C) 2008-2012 NICTA (www.nicta.com.au)
 // Copyright (C) 2008-2012 Conrad Sanderson
+// Copyright (C) 2012 Ryan Curtin
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -153,4 +154,87 @@ operator+
 
 
 
+//! addition of two sparse objects
+template<typename T1, typename T2>
+inline
+arma_hot
+typename
+enable_if2
+  <
+  (is_arma_sparse_type<T1>::value && is_arma_sparse_type<T2>::value && is_same_type<typename T1::elem_type, typename T2::elem_type>::value),
+  SpGlue<T1,T2,spglue_plus>
+  >::result
+operator+
+  (
+  const T1& x,
+  const T2& y
+  )
+  {
+  arma_extra_debug_sigprint();
+  
+  return SpGlue<T1,T2,spglue_plus>(x, y);
+  }
+
+
+
+
+//! addition of sparse and non-sparse object
+template<typename T1, typename T2>
+arma_inline
+typename
+enable_if2
+  <
+  (is_arma_sparse_type<T1>::value && is_arma_type<T2>::value && is_same_type<typename T1::elem_type, typename T2::elem_type>::value),
+  Mat<typename T1::elem_type>
+  >::result
+operator+
+  (
+  const SpBase<typename T1::elem_type, T1>& x,
+  const   Base<typename T2::elem_type, T2>& y
+  )
+  {
+  // Just call the other order (these operations are commutative)
+  return (y + x);
+  }
+
+
+
+//! addition of sparse and non-sparse object
+template<typename T1, typename T2>
+inline
+typename
+enable_if2
+  <
+  (is_arma_type<T1>::value && is_arma_sparse_type<T2>::value && is_same_type<typename T1::elem_type, typename T2::elem_type>::value),
+  Mat<typename T1::elem_type>
+  >::result
+operator+
+  (
+  const   Base<typename T1::elem_type, T1>& x,
+  const SpBase<typename T2::elem_type, T2>& y
+  )
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat<typename T1::elem_type> result(x.get_ref());
+  
+  const SpProxy<T2> pb(y.get_ref());
+  
+  arma_debug_assert_same_size( result.n_rows, result.n_cols, pb.get_n_rows(), pb.get_n_cols(), "addition" );
+  
+  typename SpProxy<T2>::const_iterator_type it = pb.begin();
+  
+  while(it.pos() < pb.get_n_nonzero())
+    {
+    const uword pos = it.col() * pb.get_n_cols() + it.row();
+    result[pos] += (*it);
+    ++it;
+    }
+  
+  return result;
+  }
+
+
+
+
 //! @}
