@@ -36,7 +36,10 @@ template<> struct is_promotable<std::complex<double>, std::complex<float> > : pu
 template<> struct is_promotable<std::complex<double>, float>                : public is_promotable_ok { typedef std::complex<double> result; };
 template<> struct is_promotable<std::complex<float>,  double>               : public is_promotable_ok { typedef std::complex<double> result; };
 
-// template<typename T> struct is_promotable<std::complex<T>, u64> : public is_promotable_ok { typedef std::complex<T> result; };
+#if defined(ARMA_64BIT_WORD)
+template<typename t> struct is_promotable<std::complex<t>, u64> : public is_promotable_ok { typedef std::complex<t> result; };
+template<typename t> struct is_promotable<std::complex<t>, s64> : public is_promotable_ok { typedef std::complex<t> result; };
+#endif
 template<typename T> struct is_promotable<std::complex<T>, s32> : public is_promotable_ok { typedef std::complex<T> result; };
 template<typename T> struct is_promotable<std::complex<T>, u32> : public is_promotable_ok { typedef std::complex<T> result; };
 template<typename T> struct is_promotable<std::complex<T>, s16> : public is_promotable_ok { typedef std::complex<T> result; };
@@ -46,7 +49,10 @@ template<typename T> struct is_promotable<std::complex<T>, u8>  : public is_prom
 
 
 template<> struct is_promotable<double, float> : public is_promotable_ok { typedef double result; };
-// template<> struct is_promotable<double, u64  > : public is_promotable_ok { typedef double result; };
+#if defined(ARMA_64BIT_WORD)
+template<> struct is_promotable<double, s64  > : public is_promotable_ok { typedef double result; };
+template<> struct is_promotable<double, u64  > : public is_promotable_ok { typedef double result; };
+#endif
 template<> struct is_promotable<double, s32  > : public is_promotable_ok { typedef double result; };
 template<> struct is_promotable<double, u32  > : public is_promotable_ok { typedef double result; };
 template<> struct is_promotable<double, s16  > : public is_promotable_ok { typedef double result; };
@@ -54,7 +60,10 @@ template<> struct is_promotable<double, u16  > : public is_promotable_ok { typed
 template<> struct is_promotable<double, s8   > : public is_promotable_ok { typedef double result; };
 template<> struct is_promotable<double, u8   > : public is_promotable_ok { typedef double result; };
 
-// template<> struct is_promotable<float, u64> : public is_promotable_ok { typedef float result; };
+#if defined(ARMA_64BIT_WORD)
+template<> struct is_promotable<float, s64> : public is_promotable_ok { typedef float result; };
+template<> struct is_promotable<float, u64> : public is_promotable_ok { typedef float result; };
+#endif
 template<> struct is_promotable<float, s32> : public is_promotable_ok { typedef float result; };
 template<> struct is_promotable<float, u32> : public is_promotable_ok { typedef float result; };
 template<> struct is_promotable<float, s16> : public is_promotable_ok { typedef float result; };
@@ -62,9 +71,21 @@ template<> struct is_promotable<float, u16> : public is_promotable_ok { typedef
 template<> struct is_promotable<float, s8 > : public is_promotable_ok { typedef float result; };
 template<> struct is_promotable<float, u8 > : public is_promotable_ok { typedef float result; };
 
-// template<> struct is_promotable<u64, u32> : public is_promotable_ok { typedef u64 result; };
-// template<> struct is_promotable<u64, u16> : public is_promotable_ok { typedef u64 result; };
-// template<> struct is_promotable<u64, u8 > : public is_promotable_ok { typedef u64 result; };
+#if defined(ARMA_64BIT_WORD)
+template<> struct is_promotable<u64, u32> : public is_promotable_ok { typedef u64 result; };
+template<> struct is_promotable<u64, u16> : public is_promotable_ok { typedef u64 result; };
+template<> struct is_promotable<u64, u8 > : public is_promotable_ok { typedef u64 result; };
+#endif
+
+#if defined(ARMA_64BIT_WORD)
+template<> struct is_promotable<s64, u64> : public is_promotable_ok { typedef s64 result; };  // float ?  
+template<> struct is_promotable<s64, u32> : public is_promotable_ok { typedef s64 result; };
+template<> struct is_promotable<s64, s32> : public is_promotable_ok { typedef s64 result; };
+template<> struct is_promotable<s64, s16> : public is_promotable_ok { typedef s64 result; };
+template<> struct is_promotable<s64, u16> : public is_promotable_ok { typedef s64 result; };
+template<> struct is_promotable<s64, s8 > : public is_promotable_ok { typedef s64 result; };
+template<> struct is_promotable<s64, u8 > : public is_promotable_ok { typedef s64 result; };
+#endif
 
 template<> struct is_promotable<s32, u32> : public is_promotable_ok { typedef s32 result; };  // float ?  
 template<> struct is_promotable<s32, s16> : public is_promotable_ok { typedef s32 result; };
@@ -98,7 +119,10 @@ template<> struct is_promotable<std::complex<float>, std::complex<double> > : pu
 template<> struct is_promotable<float,               std::complex<double> > : public is_promotable_ok { typedef std::complex<double> result; };
 template<> struct is_promotable<double,              std::complex<float>  > : public is_promotable_ok { typedef std::complex<double> result; };
 
-// template<typename T> struct is_promotable<u64, std::complex<T> > : public is_promotable_ok { typedef std::complex<T> result; };
+#if defined(ARMA_64BIT_WORD)
+template<typename T> struct is_promotable<s64, std::complex<T> > : public is_promotable_ok { typedef std::complex<T> result; };
+template<typename T> struct is_promotable<u64, std::complex<T> > : public is_promotable_ok { typedef std::complex<T> result; };
+#endif
 template<typename T> struct is_promotable<s32, std::complex<T> > : public is_promotable_ok { typedef std::complex<T> result; };
 template<typename T> struct is_promotable<u32, std::complex<T> > : public is_promotable_ok { typedef std::complex<T> result; };
 template<typename T> struct is_promotable<s16, std::complex<T> > : public is_promotable_ok { typedef std::complex<T> result; };
@@ -108,7 +132,10 @@ template<typename T> struct is_promotable<u8,  std::complex<T> > : public is_pro
 
 
 template<> struct is_promotable<float, double> : public is_promotable_ok { typedef double result; };
-// template<> struct is_promotable<u64  , double> : public is_promotable_ok { typedef double result; };
+#if defined(ARMA_64BIT_WORD)
+template<> struct is_promotable<s64  , double> : public is_promotable_ok { typedef double result; };
+template<> struct is_promotable<u64  , double> : public is_promotable_ok { typedef double result; };
+#endif
 template<> struct is_promotable<s32  , double> : public is_promotable_ok { typedef double result; };
 template<> struct is_promotable<u32  , double> : public is_promotable_ok { typedef double result; };
 template<> struct is_promotable<s16  , double> : public is_promotable_ok { typedef double result; };
@@ -116,7 +143,10 @@ template<> struct is_promotable<u16  , double> : public is_promotable_ok { typed
 template<> struct is_promotable<s8   , double> : public is_promotable_ok { typedef double result; };
 template<> struct is_promotable<u8   , double> : public is_promotable_ok { typedef double result; };
 
-// template<> struct is_promotable<u64, float> : public is_promotable_ok { typedef float result; };
+#if defined(ARMA_64BIT_WORD)
+template<> struct is_promotable<s64, float> : public is_promotable_ok { typedef float result; };
+template<> struct is_promotable<u64, float> : public is_promotable_ok { typedef float result; };
+#endif
 template<> struct is_promotable<s32, float> : public is_promotable_ok { typedef float result; };
 template<> struct is_promotable<u32, float> : public is_promotable_ok { typedef float result; };
 template<> struct is_promotable<s16, float> : public is_promotable_ok { typedef float result; };
@@ -124,9 +154,20 @@ template<> struct is_promotable<u16, float> : public is_promotable_ok { typedef
 template<> struct is_promotable<s8 , float> : public is_promotable_ok { typedef float result; };
 template<> struct is_promotable<u8 , float> : public is_promotable_ok { typedef float result; };
 
-// template<> struct is_promotable<u32, u64> : public is_promotable_ok { typedef u64 result; };
-// template<> struct is_promotable<u16, u64> : public is_promotable_ok { typedef u64 result; };
-// template<> struct is_promotable<u8,  u64> : public is_promotable_ok { typedef u64 result; };
+#if defined(ARMA_64BIT_WORD)
+template<> struct is_promotable<u32, u64> : public is_promotable_ok { typedef u64 result; };
+template<> struct is_promotable<u16, u64> : public is_promotable_ok { typedef u64 result; };
+template<> struct is_promotable<u8,  u64> : public is_promotable_ok { typedef u64 result; };
+#endif
+
+#if defined(ARMA_64BIT_WORD)
+template<> struct is_promotable<u64, s64> : public is_promotable_ok { typedef s64 result; };  // float ?  
+template<> struct is_promotable<u32, s64> : public is_promotable_ok { typedef s64 result; };
+template<> struct is_promotable<s16, s64> : public is_promotable_ok { typedef s64 result; };
+template<> struct is_promotable<u16, s64> : public is_promotable_ok { typedef s64 result; };
+template<> struct is_promotable<s8 , s64> : public is_promotable_ok { typedef s64 result; };
+template<> struct is_promotable<u8 , s64> : public is_promotable_ok { typedef s64 result; };
+#endif
 
 template<> struct is_promotable<u32, s32> : public is_promotable_ok { typedef s32 result; };  // float ?  
 template<> struct is_promotable<s16, s32> : public is_promotable_ok { typedef s32 result; };
@@ -157,8 +198,7 @@ struct promote_type
   {
   inline static void check()
     {
-    arma_static_assert< is_promotable<T1,T2>::value > ERROR___UNSUPPORTED_MIXTURE_OF_TYPES;
-    ERROR___UNSUPPORTED_MIXTURE_OF_TYPES = ERROR___UNSUPPORTED_MIXTURE_OF_TYPES;
+    arma_type_check(( is_promotable<T1,T2>::value == false ));
     }
   
   typedef typename is_promotable<T1,T2>::result result;
